package com.ruoyi.web.controller.system;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.service.ISysPostService;
import com.ruoyi.system.service.ISysRoleService;
import com.ruoyi.system.service.ISysUserService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 涉密人员统计
 */
@Controller
@RequestMapping("/system/usernum")
public class SysUsernumController extends BaseController {
    private String prefix = "system/usernum";

    @Autowired
    private ISysUserService userService;

    @Autowired
    private ISysPostService postService;
    @Autowired
    private ISysRoleService roleService;

    @RequiresPermissions("system:usernum:view")
    @GetMapping()
    public String user()
    {
        return prefix + "/usernum";
    }

    /**
     * 用户列表
     * @param user
     * @return
     */
    @RequiresPermissions("system:usernum:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(SysUser user)
    {
        startPage();
        List<SysUser> list = userService.selectUserList(user);
        return getDataTable(list);
    }

    /**
     * 导出用户
     * @param user
     * @return
     */
    @Log(title = "用户统计", businessType = BusinessType.EXPORT)
    @RequiresPermissions("system:usernum:export")
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(SysUser user)
    {
        List<SysUser> list = userService.selectUserList(user);
        ExcelUtil<SysUser> util = new ExcelUtil<SysUser>(SysUser.class);
        return util.exportExcel(list, "用户统计数据");
    }

    /**
     * 用户详情
     * @param userId
     * @param mmap
     * @return
     */
    @RequiresPermissions("system:usernum:detail")
    @GetMapping("/detail/{userId}")
    public String detail(@PathVariable("userId") Long userId, ModelMap mmap){
        mmap.put("user",userService.selectUserById(userId));
        mmap.put("role",roleService.selectRolesByUserIds(userId));
        mmap.put("post",postService.selectPostsByUserIds(userId));
        return prefix + "/detail";
    }

    /**
     * 打印
     */
    @RequiresPermissions("system:usernum:print")
    @PostMapping("/print")
    @ResponseBody
    public AjaxResult print(SysUser user){
        List<SysUser> sysUsers = userService.selectUserList(user);
        return AjaxResult.success(sysUsers);
    }
}
